==> jdk-17.0.12_windows-x64_bin.zip: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sg.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sg extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "dir\u00e2m t\u00ee \u00e2Emir\u00e2ti t\u00ee Ar\u00e2bo \u00d4ko" },
            { "aoa", "kw\u00e2nza t\u00ee Angol\u00e4a" },
            { "aud", "dol\u00e4ra t\u00ee Ostral\u00efi" },
            { "bhd", "dol\u00f9ara t\u00ee Bahr\u00e2ina" },
            { "bif", "far\u00e2nga t\u00ee Burund\u00efi" },
            { "bwp", "p\u00fbla t\u00ee Botswana" },
            { "cad", "dol\u00e4ra t\u00ee kanad\u00e4a" },
            { "cdf", "far\u00e2nga t\u00ee Kong\u00f6o" },
            { "chf", "far\u00e2nga t\u00ee S\u00fb\u00eesi" },
            { "cny", "yuan renminbi t\u00ee Sh\u00eeni" },
            { "cve", "esk\u00fb\u00eado t\u00ee K\u00e2po-V\u00eare" },
            { "djf", "far\u00e2nga t\u00ee Dibut\u00efi" },
            { "dzd", "din\u00e4ri t\u00ee Alzer\u00efi" },
            { "egp", "p\u00f4ndo t\u00ee K\u00e2mit\u00e2" },
            { "ern", "nakafa t\u00ee Eritr\u00ebe" },
            { "etb", "bir t\u00ee Etiop\u00efi" },
            { "eur", "zor\u00f6o" },
            { "gbp", "p\u00f4ndo t\u00ee Angl\u00ebe" },
            { "ghc", "s\u00eadi t\u00ee Gan\u00e4a" },
            { "gmd", "dalasi t\u00ee gamb\u00efi" },
            { "gns", "sili t\u00ee Gin\u00ebe" },
            { "inr", "rup\u00efi t\u00ee \u00cannde" },
            { "jpy", "y\u00eani t\u00ee Zap\u00f6n" },
            { "kes", "shil\u00eengi t\u00ee Keny\u00e4a" },
            { "kmf", "far\u00e2nga t\u00ee K\u00f6m\u00f4ro" },
            { "lrd", "dol\u00e4ra t\u00ee Liber\u00efa" },
            { "lsl", "loti t\u00ee Les\u00f4tho" },
            { "lyd", "din\u00e4ar t\u00ee Lib\u00efi" },
            { "mad", "dir\u00e2m t\u00ee Mar\u00f4ko" },
            { "mga", "ari\u00e2ri t\u00ee Madagasik\u00e4ra" },
            { "mro", "ug\u00eeya t\u00ee Moritan\u00efi (1973\u20132017)" },
            { "mru", "ug\u00eeya t\u00ee Moritan\u00efi" },
            { "mur", "rup\u00efi t\u00ee M\u00f6r\u00eesi" },
            { "mwk", "kw\u00e2tia t\u00ee Malaw\u00efi" },
            { "mzm", "metikala t\u00ee Mozamb\u00eeka" },
            { "nad", "dol\u00e4ra t\u00ee Namib\u00efi" },
            { "ngn", "n\u00e2\u00eera t\u00ee Nizer\u00efa" },
            { "rwf", "far\u00e2nga t\u00ee Ruand\u00e4a" },
            { "sar", "ri\u00e2li t\u00ee Sa\u00fbdi Arab\u00efi" },
            { "scr", "rup\u00efi t\u00ee S\u00ebysh\u00eale" },
            { "sdg", "p\u00f4ndo t\u00ee Sud\u00e4an" },
            { "shp", "p\u00f4ndo t\u00ee Z\u00fb\u00e2 S\u00eant-Hel\u00eana" },
            { "sll", "le\u00f4ne t\u00ee Sier\u00e2-Le\u00f4ne" },
            { "sos", "shil\u00eengi t\u00ee Somal\u00efi" },
            { "std", "d\u00f4bra t\u00ee S\u00e2\u00f4 Tom\u00eb na Prins\u00eepe (1977\u20132017)" },
            { "stn", "d\u00f4bra t\u00ee S\u00e2\u00f4 Tom\u00eb na Prins\u00eepe" },
            { "szl", "lilang\u00f9eni t\u00ee Swaz\u00efl\u00e2nde" },
            { "tnd", "din\u00e4ra t\u00ee Tuniz\u00efi" },
            { "tzs", "shil\u00eengi t\u00ee Tanzan\u00efi" },
            { "ugx", "shil\u00eengi t\u00ee Ugand\u00e4a" },
            { "usd", "dol$ara tt\u00ee \u00e4Let\u00e4a-\u00d4ko t\u00ee Amer\u00eeka" },
            { "xaf", "far\u00e2nga CFA (BEAC)" },
            { "xof", "far\u00e2nga CFA (BCEAO)" },
            { "zar", "r\u00e2nde t\u00ee Mbongo-Afr\u00eeka" },
            { "zmk", "kw\u00e2tia t\u00ee Zamb\u00efi (1968\u20132012)" },
            { "zmw", "kw\u00e2tia t\u00ee Zamb\u00efi" },
            { "zwd", "dol\u00e4ra t\u00ee Zimb\u00e4bwe" },
        };
        return data;
    }
}

==> jdk-22.0.2_windows-x64_bin.zip: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sg.java <==
/*
 * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sg extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "dir\u00e2m t\u00ee \u00e2Emir\u00e2ti t\u00ee Ar\u00e2bo \u00d4ko" },
            { "aoa", "kw\u00e2nza t\u00ee Angol\u00e4a" },
            { "aud", "dol\u00e4ra t\u00ee Ostral\u00efi" },
            { "bhd", "dol\u00f9ara t\u00ee Bahr\u00e2ina" },
            { "bif", "far\u00e2nga t\u00ee Burund\u00efi" },
            { "bwp", "p\u00fbla t\u00ee Botswana" },
            { "cad", "dol\u00e4ra t\u00ee kanad\u00e4a" },
            { "cdf", "far\u00e2nga t\u00ee Kong\u00f6o" },
            { "chf", "far\u00e2nga t\u00ee S\u00fb\u00eesi" },
            { "cny", "yuan renminbi t\u00ee Sh\u00eeni" },
            { "cve", "esk\u00fb\u00eado t\u00ee K\u00e2po-V\u00eare" },
            { "djf", "far\u00e2nga t\u00ee Dibut\u00efi" },
            { "dzd", "din\u00e4ri t\u00ee Alzer\u00efi" },
            { "egp", "p\u00f4ndo t\u00ee K\u00e2mit\u00e2" },
            { "ern", "nakafa t\u00ee Eritr\u00ebe" },
            { "etb", "bir t\u00ee Etiop\u00efi" },
            { "eur", "zor\u00f6o" },
            { "gbp", "p\u00f4ndo t\u00ee Angl\u00ebe" },
            { "ghc", "s\u00eadi t\u00ee Gan\u00e4a" },
            { "gmd", "dalasi t\u00ee gamb\u00efi" },
            { "gns", "sili t\u00ee Gin\u00ebe" },
            { "inr", "rup\u00efi t\u00ee \u00cannde" },
            { "jpy", "y\u00eani t\u00ee Zap\u00f6n" },
            { "kes", "shil\u00eengi t\u00ee Keny\u00e4a" },
            { "kmf", "far\u00e2nga t\u00ee K\u00f6m\u00f4ro" },
            { "lrd", "dol\u00e4ra t\u00ee Liber\u00efa" },
            { "lsl", "loti t\u00ee Les\u00f4tho" },
            { "lyd", "din\u00e4ar t\u00ee Lib\u00efi" },
            { "mad", "dir\u00e2m t\u00ee Mar\u00f4ko" },
            { "mga", "ari\u00e2ri t\u00ee Madagasik\u00e4ra" },
            { "mro", "ug\u00eeya t\u00ee Moritan\u00efi (1973\u20132017)" },
            { "mru", "ug\u00eeya t\u00ee Moritan\u00efi" },
            { "mur", "rup\u00efi t\u00ee M\u00f6r\u00eesi" },
            { "mwk", "kw\u00e2tia t\u00ee Malaw\u00efi" },
            { "mzm", "metikala t\u00ee Mozamb\u00eeka" },
            { "nad", "dol\u00e4ra t\u00ee Namib\u00efi" },
            { "ngn", "n\u00e2\u00eera t\u00ee Nizer\u00efa" },
            { "rwf", "far\u00e2nga t\u00ee Ruand\u00e4a" },
            { "sar", "ri\u00e2li t\u00ee Sa\u00fbdi Arab\u00efi" },
            { "scr", "rup\u00efi t\u00ee S\u00ebysh\u00eale" },
            { "sdg", "p\u00f4ndo t\u00ee Sud\u00e4an" },
            { "shp", "p\u00f4ndo t\u00ee Z\u00fb\u00e2 S\u00eant-Hel\u00eana" },
            { "sle", "le\u00f4ne t\u00ee Sier\u00e2-Le\u00f4ne" },
            { "sll", "le\u00f4ne t\u00ee Sier\u00e2-Le\u00f4ne (1964\u20142022)" },
            { "sos", "shil\u00eengi t\u00ee Somal\u00efi" },
            { "std", "d\u00f4bra t\u00ee S\u00e2\u00f4 Tom\u00eb na Prins\u00eepe (1977\u20132017)" },
            { "stn", "d\u00f4bra t\u00ee S\u00e2\u00f4 Tom\u00eb na Prins\u00eepe" },
            { "szl", "lilang\u00f9eni t\u00ee Swaz\u00efl\u00e2nde" },
            { "tnd", "din\u00e4ra t\u00ee Tuniz\u00efi" },
            { "tzs", "shil\u00eengi t\u00ee Tanzan\u00efi" },
            { "ugx", "shil\u00eengi t\u00ee Ugand\u00e4a" },
            { "usd", "dol$ara tt\u00ee \u00e4Let\u00e4a-\u00d4ko t\u00ee Amer\u00eeka" },
            { "xaf", "far\u00e2nga CFA (BEAC)" },
            { "xof", "far\u00e2nga CFA (BCEAO)" },
            { "zar", "r\u00e2nde t\u00ee Mbongo-Afr\u00eeka" },
            { "zmk", "kw\u00e2tia t\u00ee Zamb\u00efi (1968\u20132012)" },
            { "zmw", "kw\u00e2tia t\u00ee Zamb\u00efi" },
            { "zwd", "dol\u00e4ra t\u00ee Zimb\u00e4bwe" },
        };
        return data;
    }
}
